@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: io90pwm2b.h,v 1.3 2007/12/19 00:29:06 arcanum Exp $ */
+/* $Id: io90pwm2b.h,v 1.3.2.5 2008/03/19 21:05:23 arcanum Exp $ */
 
 /* avr/io90pwm2b.h - definitions for AT90PWM2B */
 
@@ -82,10 +82,34 @@
 #define PORTB7 7
       
 #define PINC _SFR_IO8(0x06)
+#define PINC0 0
+#define PINC1 1
+#define PINC2 2
+#define PINC3 3
+#define PINC4 4
+#define PINC5 5
+#define PINC6 6
+#define PINC7 7
 
 #define DDRC _SFR_IO8(0x07)
+#define DDC0 0
+#define DDC1 1
+#define DDC2 2
+#define DDC3 3
+#define DDC4 4
+#define DDC5 5
+#define DDC6 6
+#define DDC7 7
 
 #define PORTC _SFR_IO8(0x08)
+#define PORTC0 0
+#define PORTC1 1
+#define PORTC2 2
+#define PORTC3 3
+#define PORTC4 4
+#define PORTC5 5
+#define PORTC6 6
+#define PORTC7 7
 
 #define PIND _SFR_IO8(0x09)
 #define PIND0 0
@@ -177,11 +201,13 @@
 #define INTF0 0
 #define INTF1 1
 #define INTF2 2
+#define INTF3 3
 
 #define EIMSK _SFR_IO8(0x1D)
 #define INT0 0
 #define INT1 1
 #define INT2 2
+#define INT3 3
 
 #define GPIOR0 _SFR_IO8(0x1E)
 #define GPIOR00 0
@@ -211,6 +237,8 @@
 #define EEDR6 6
 #define EEDR7 7
 
+#define EEAR _SFR_IO16(0x21)
+
 #define EEARL _SFR_IO8(0x21)
 #define EEARL0 0
 #define EEARL1 1
@@ -388,6 +416,8 @@
 #define ISC11 3
 #define ISC20 4
 #define ISC21 5
+#define ISC30 6
+#define ISC31 7
 
 #define TIMSK0 _SFR_MEM8(0x6E)
 #define TOIE0 0
@@ -401,8 +431,22 @@
 #define ICIE1 5
 
 #define AMP0CSR _SFR_MEM8(0x76)
+#define AMP0TS0 0
+#define AMP0TS1 1
+#define AMP0G0 4
+#define AMP0G1 5
+#define AMP0IS 6
+#define AMP0EN 7
 
 #define AMP1CSR _SFR_MEM8(0x77)
+#define AMP1TS0 0
+#define AMP1TS1 1
+#define AMP1G0 4
+#define AMP1G1 5
+#define AMP1IS 6
+#define AMP1EN 7
+
+#define ADC _SFR_MEM16(0x78)
 
 #define ADCL _SFR_MEM8(0x78)
 #define ADCL0 0
@@ -414,6 +458,16 @@
 #define ADCL6 6
 #define ADCL7 7
 
+#define ADCH _SFR_MEM8(0x79)
+#define ADCH0 0
+#define ADCH1 1
+#define ADCH2 2
+#define ADCH3 3
+#define ADCH4 4
+#define ADCH5 5
+#define ADCH6 6
+#define ADCH7 7
+
 #define ADCSRA _SFR_MEM8(0x7A)
 #define ADPS0 0
 #define ADPS1 1
@@ -502,7 +556,7 @@
 #define TCNT1H6 6
 #define TCNT1H7 7
 
-#define ICR1 _SFR_MEM8(0x86)
+#define ICR1 _SFR_MEM16(0x86)
 
 #define ICR1L _SFR_MEM8(0x86)
 #define ICR1L0 0
@@ -585,8 +639,20 @@
 #define PSEIE0 5
 
 #define PIFR1 _SFR_MEM8(0xA2)
+#define PEOP1 0
+#define PRN10 1
+#define PRN11 2
+#define PEV1A 3
+#define PEV1B 4
+#define PSEI1 5
+#define POAC1A 6
+#define POAC1B 7
 
 #define PIM1 _SFR_MEM8(0xA3)
+#define PEOPE1 0
+#define PEVE1A 3
+#define PEVE1B 4
+#define PSEIE1 5
 
 #define PIFR2 _SFR_MEM8(0xA4)
 #define PEOP2 0
@@ -915,44 +981,144 @@
 #define PCST0 7
 
 #define PSOC1 _SFR_MEM8(0xE0)
+#define POEN1A 0
+#define POEN1B 2
+#define PSYNC1_0 4
+#define PSYNC1_1 5
 
 #define OCR1SA _SFR_MEM16(0xE2)
 
 #define OCR1SAL _SFR_MEM8(0xE2)
+#define OCR1SA_0 0
+#define OCR1SA_1 1
+#define OCR1SA_2 2
+#define OCR1SA_3 3
+#define OCR1SA_4 4
+#define OCR1SA_5 5
+#define OCR1SA_6 6
+#define OCR1SA_7 7
 
 #define OCR1SAH _SFR_MEM8(0xE3)
+#define OCR1SA_8 0
+#define OCR1SA_9 1
+#define OCR1SA_10 2
+#define OCR1SA_11 3
 
 #define OCR1RA _SFR_MEM16(0xE4)
 
 #define OCR1RAL _SFR_MEM8(0xE4)
+#define OCR1RA_0 0
+#define OCR1RA_1 1
+#define OCR1RA_2 2
+#define OCR1RA_3 3
+#define OCR1RA_4 4
+#define OCR1RA_5 5
+#define OCR1RA_6 6
+#define OCR1RA_7 7
 
 #define OCR1RAH _SFR_MEM8(0xE5)
+#define OCR1RA_8 0
+#define OCR1RA_9 1
+#define OCR1RA_10 2
+#define OCR1RA_11 3
 
 #define OCR1SB _SFR_MEM16(0xE6)
 
 #define OCR1SBL _SFR_MEM8(0xE6)
+#define OCR1SB_0 0
+#define OCR1SB_1 1
+#define OCR1SB_2 2
+#define OCR1SB_3 3
+#define OCR1SB_4 4
+#define OCR1SB_5 5
+#define OCR1SB_6 6
+#define OCR1SB_7 7
 
 #define OCR1SBH _SFR_MEM8(0xE7)
+#define OCR1SB_8 0
+#define OCR1SB_9 1
+#define OCR1SB_10 2
+#define OCR1SB_11 3
 
 #define OCR1RB _SFR_MEM16(0xE8)
 
 #define OCR1RBL _SFR_MEM8(0xE8)
+#define OCR1RB_0 0
+#define OCR1RB_1 1
+#define OCR1RB_2 2
+#define OCR1RB_3 3
+#define OCR1RB_4 4
+#define OCR1RB_5 5
+#define OCR1RB_6 6
+#define OCR1RB_7 7
 
 #define OCR1RBH _SFR_MEM8(0xE9)
+#define OCR1RB_8 0
+#define OCR1RB_9 1
+#define OCR1RB_10 2
+#define OCR1RB_11 3
+#define OCR1RB_12 4
+#define OCR1RB_13 5
+#define OCR1RB_14 6
+#define OCR1RB_15 7
 
 #define PCNF1 _SFR_MEM8(0xEA)
+#define PCLKSEL1 1
+#define POP1 2
+#define PMODE10 3
+#define PMODE11 4
+#define PLOCK1 5
+#define PALOCK1 6
+#define PFIFTY1 7
 
 #define PCTL1 _SFR_MEM8(0xEB)
+#define PRUN1 0
+#define PCCYC1 1
+#define PARUN1 2
+#define PAOC1A 3
+#define PAOC1B 4
+#define PBFM1 5
+#define PPRE10 6
+#define PPRE11 7
 
 #define PFRC1A _SFR_MEM8(0xEC)
+#define PRFM1A0 0
+#define PRFM1A1 1
+#define PRFM1A2 2
+#define PRFM1A3 3
+#define PFLTE1A 4
+#define PELEV1A 5
+#define PISEL1A 6
+#define PCAE1A 7
 
 #define PFRC1B _SFR_MEM8(0xED)
+#define PRFM1B0 0
+#define PRFM1B1 1
+#define PRFM1B2 2
+#define PRFM1B3 3
+#define PFLTE1B 4
+#define PELEV1B 5
+#define PISEL1B 6
+#define PCAE1B 7
 
 #define PICR1 _SFR_MEM16(0xEE)
 
 #define PICR1L _SFR_MEM8(0xEE)
+#define PICR1_0 0
+#define PICR1_1 1
+#define PICR1_2 2
+#define PICR1_3 3
+#define PICR1_4 4
+#define PICR1_5 5
+#define PICR1_6 6
+#define PICR1_7 7
 
 #define PICR1H _SFR_MEM8(0xEF)
+#define PICR1_8 0
+#define PICR1_9 1
+#define PICR1_10 2
+#define PICR1_11 3
+#define PCST1 7
 
 #define PSOC2 _SFR_MEM8(0xF0)
 #define POEN2A 0
@@ -999,7 +1165,8 @@
 #define OCR2RA_1 1
 #define OCR2RA_2 2
 #define OCR2RA_3 3
-#define OCR2RA_4 4#define OCR2RA_5 5
+#define OCR2RA_4 4
+#define OCR2RA_5 5
 #define OCR2RA_6 6
 #define OCR2RA_7 7
 
@@ -1127,7 +1294,7 @@
 #define TIMER1_COMPB_vect   _VECTOR(13)  /* Timer/Counter Compare Match B */
 /* Vector 14, Reserved */
 #define TIMER1_OVF_vect     _VECTOR(15)  /* Timer/Counter1 Overflow */
-#define TIMER0_COMP A_vect  _VECTOR(16)  /* Timer/Counter0 Compare Match A */
+#define TIMER0_COMPA_vect   _VECTOR(16)  /* Timer/Counter0 Compare Match A */
 #define TIMER0_OVF_vect     _VECTOR(17)  /* Timer/Counter0 Overflow */
 #define ADC_vect            _VECTOR(18)  /* ADC Conversion Complete */
 #define INT1_vect           _VECTOR(19)  /* External Interrupt Request 1 */
@@ -1150,7 +1317,8 @@
 
 /* Memory Sizes */
 #define RAMEND         0x2FF
-#define XRAMEND        0x00
+#define XRAMSIZE       0
+#define XRAMEND        (RAMEND + XRAMSIZE)
 #define E2END          0x1FF
 #define FLASHEND       0x1FFF
 #define SPM_PAGESIZE   32
@@ -1162,38 +1330,38 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0  ~_BV(0)  /* Select Clock Source */
-#define CKSEL1  ~_BV(1)  /* Select Clock Source */
-#define CKSEL2  ~_BV(2)  /* Select Clock Source */
-#define CKSEL3  ~_BV(3)  /* Select Clock Source */
-#define SUT0    ~_BV(4)  /* Select start-up time */
-#define SUT1    ~_BV(5)  /* Select start-up time */
-#define CKOUT   ~_BV(6) /* Oscillator output option */
-#define CLKDIV8 ~_BV(7)  /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+#define FUSE_CKSEL0  ~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1  ~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2  ~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3  ~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0    ~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1    ~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT   ~_BV(6) /* Oscillator output option */
+#define FUSE_CLKDIV8 ~_BV(7)  /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 
 /* High Fuse Byte */
-#define BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define BODLEVEL2 ~_BV(2)  /* Brown out detector trigger level */
-#define EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON     ~_BV(4)  /* Watchdog timer always on */
-#define SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL  ~_BV(7)  /* External Reset Disable */
-#define HFUSE_DEFAULT (SPIEN)    
+#define FUSE_BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 ~_BV(2)  /* Brown out detector trigger level */
+#define FUSE_EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     ~_BV(4)  /* Watchdog timer always on */
+#define FUSE_SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      ~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  ~_BV(7)  /* External Reset Disable */
+#define HFUSE_DEFAULT (FUSE_SPIEN)    
 
 
 /* Extended Fuse Byte */
-#define BOOTRST ~_BV(0)  /* Select Reset Vector */
-#define BOOTSZ0 ~_BV(1)  /* Select Boot Size */
-#define BOOTSZ1 ~_BV(2)  /* Select Boot Size */
-#define PSCRV   ~_BV(4)  /* PSCOUT Reset Value */
-#define PSC0RB  ~_BV(5)  /* PSC0 Reset Behaviour */
-#define PSC1RB  ~_BV(6)  /* PSC1 Reset Behaviour */
-#define PSC2RB  ~_BV(7)  /* PSC2 Reset Behaviour */
-#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+#define FUSE_BOOTRST ~_BV(0)  /* Select Reset Vector */
+#define FUSE_BOOTSZ0 ~_BV(1)  /* Select Boot Size */
+#define FUSE_BOOTSZ1 ~_BV(2)  /* Select Boot Size */
+#define FUSE_PSCRV   ~_BV(4)  /* PSCOUT Reset Value */
+#define FUSE_PSC0RB  ~_BV(5)  /* PSC0 Reset Behaviour */
+#define FUSE_PSC1RB  ~_BV(6)  /* PSC1 Reset Behaviour */
+#define FUSE_PSC2RB  ~_BV(7)  /* PSC2 Reset Behaviour */
+#define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
 /* Lock Bits */
