@@ -30,7 +30,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom169.h,v 1.24.2.2 2007/12/12 04:39:26 arcanum Exp $ */
+/* $Id: iom169.h,v 1.26.2.2 2008/01/06 20:10:44 arcanum Exp $ */
 
 /* iom169.h - definitions for ATmega169 */
 
@@ -1063,31 +1063,31 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0      ~_BV(0)
-#define CKSEL1      ~_BV(1)
-#define CKSEL2      ~_BV(2)
-#define CKSEL3      ~_BV(3)
-#define SUT0        ~_BV(4)
-#define SUT1        ~_BV(5)
-#define CKOUT       ~_BV(6)
-#define CKDIV8      ~_BV(7)
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+#define FUSE_CKSEL0      ~_BV(0)
+#define FUSE_CKSEL1      ~_BV(1)
+#define FUSE_CKSEL2      ~_BV(2)
+#define FUSE_CKSEL3      ~_BV(3)
+#define FUSE_SUT0        ~_BV(4)
+#define FUSE_SUT1        ~_BV(5)
+#define FUSE_CKOUT       ~_BV(6)
+#define FUSE_CKDIV8      ~_BV(7)
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define BOOTRST     ~_BV(0)
-#define BOOTSZ0     ~_BV(1)
-#define BOOTSZ1     ~_BV(2)
-#define EESAVE      ~_BV(3)
-#define WDTON       ~_BV(4)
-#define SPIEN       ~_BV(5)
-#define JTAGEN      ~_BV(6)
-#define OCDEN       ~_BV(7)
-#define HFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1 & SPIEN & JTAGEN)
+#define FUSE_BOOTRST     ~_BV(0)
+#define FUSE_BOOTSZ0     ~_BV(1)
+#define FUSE_BOOTSZ1     ~_BV(2)
+#define FUSE_EESAVE      ~_BV(3)
+#define FUSE_WDTON       ~_BV(4)
+#define FUSE_SPIEN       ~_BV(5)
+#define FUSE_JTAGEN      ~_BV(6)
+#define FUSE_OCDEN       ~_BV(7)
+#define HFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1 & FUSE_SPIEN & FUSE_JTAGEN)
 
 /* Extended Fuse Byte */
-#define BODLEVEL0   ~_BV(1)
-#define BODLEVEL1   ~_BV(2)
-#define BODLEVEL2   ~_BV(3)
+#define FUSE_BODLEVEL0   ~_BV(1)
+#define FUSE_BODLEVEL1   ~_BV(2)
+#define FUSE_BODLEVEL2   ~_BV(3)
 #define EFUSE_DEFAULT (0xFF)
 
 
