@@ -29,7 +29,7 @@
   POSSIBILITY OF SUCH DAMAGE. 
 */
 
-/* $Id: iom88p.h,v 1.3 2007/12/18 21:04:26 arcanum Exp $ */
+/* $Id: iom88p.h,v 1.3.2.6 2008/03/19 21:25:13 arcanum Exp $ */
 
 /* avr/iom88p.h - definitions for ATmega88P. */
 
@@ -163,6 +163,10 @@
 #define INTF0 0
 #define INTF1 1
 
+#define EIMSK _SFR_IO8(0x1D)
+#define INT0 0
+#define INT1 1
+
 #define GPIOR0 _SFR_IO8(0x1E)
 #define GPIOR00 0
 #define GPIOR01 1
@@ -191,7 +195,7 @@
 #define EEDR6 6
 #define EEDR7 7
 
-#define EEAR _SFR_IO8(0x21)
+#define EEAR _SFR_IO16(0x21)
 
 #define EEARL _SFR_IO8(0x21)
 #define EEAR0 0
@@ -206,6 +210,8 @@
 #define EEARH _SFR_IO8(0x22)
 #define EEAR8 0
 
+#define EEPROM_REG_LOCATIONS 1F2021
+
 #define GTCCR _SFR_IO8(0x23)
 #define PSRSYNC 0
 #define PSRASY 1
@@ -325,6 +331,8 @@
 #define WDRF 3
 
 #define MCUCR _SFR_IO8(0x35)
+#define IVCE 0 
+#define IVSEL 1
 #define PUD 4
 #define BODSE 5
 #define BODS 6
@@ -733,7 +741,9 @@
 #define UCSR0C _SFR_MEM8(0xC2)
 #define UCPOL0 0
 #define UCSZ00 1
+#define UCPHA0 1
 #define UCSZ01 2
+#define UDORD0 2
 #define USBS0 3
 #define UPM00 4
 #define UPM01 5
@@ -743,20 +753,20 @@
 #define UBRR0 _SFR_MEM16(0xC4)
 
 #define UBRR0L _SFR_MEM8(0xC4)
-#define UBRR0 0
-#define UBRR1 1
-#define UBRR2 2
-#define UBRR3 3
-#define UBRR4 4
-#define UBRR5 5
-#define UBRR6 6
-#define UBRR7 7
+#define UBRR0_0 0
+#define UBRR0_1 1
+#define UBRR0_2 2
+#define UBRR0_3 3
+#define UBRR0_4 4
+#define UBRR0_5 5
+#define UBRR0_6 6
+#define UBRR0_7 7
 
 #define UBRR0H _SFR_MEM8(0xC5)
-#define UBRR8 0
-#define UBRR9 1
-#define UBRR10 2
-#define UBRR11 3
+#define UBRR0_8 0
+#define UBRR0_9 1
+#define UBRR0_10 2
+#define UBRR0_11 3
 
 #define UDR0 _SFR_MEM8(0xC6)
 #define UDR0_0 0
@@ -805,7 +815,8 @@
 /* Constants */
 #define SPM_PAGESIZE 32
 #define RAMEND       0x4FF     /* Last On-Chip SRAM Location */
-#define XRAMEND      0
+#define XRAMSIZE     0
+#define XRAMEND      (RAMEND + XRAMSIZE)
 #define E2END        0x1FF
 #define FLASHEND     0x1FFF
 
@@ -815,30 +826,32 @@
 #define FUSE_MEMORY_SIZE 3
 
 /* Low Fuse Byte */
-#define CKSEL0 ~_BV(0)  /* Select Clock Source */
-#define CKSEL1 ~_BV(1)  /* Select Clock Source */
-#define CKSEL2 ~_BV(2)  /* Select Clock Source */
-#define CKSEL3 ~_BV(3)  /* Select Clock Source */
-#define SUT0   ~_BV(4)  /* Select start-up time */
-#define SUT1   ~_BV(5)  /* Select start-up time */
-#define CKOUT  ~_BV(6)  /* Clock output */
-#define CKDIV8 ~_BV(7) /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+#define FUSE_CKSEL0 ~_BV(0)  /* Select Clock Source */
+#define FUSE_CKSEL1 ~_BV(1)  /* Select Clock Source */
+#define FUSE_CKSEL2 ~_BV(2)  /* Select Clock Source */
+#define FUSE_CKSEL3 ~_BV(3)  /* Select Clock Source */
+#define FUSE_SUT0   ~_BV(4)  /* Select start-up time */
+#define FUSE_SUT1   ~_BV(5)  /* Select start-up time */
+#define FUSE_CKOUT  ~_BV(6)  /* Clock output */
+#define FUSE_CKDIV8 ~_BV(7) /* Divide clock by 8 */
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_CKSEL2 & FUSE_CKSEL3 & FUSE_SUT0 & FUSE_CKDIV8)
 
 /* High Fuse Byte */
-#define BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
-#define BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
-#define BODLEVEL2 ~_BV(2)  /* Brown-out Detector trigger level */
-#define EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON     ~_BV(4)  /* Watchdog Timer Always On */
-#define SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN      ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL  ~_BV(7)  /* External reset disable */
-#define HFUSE_DEFAULT (SPIEN)
+#define FUSE_BODLEVEL0 ~_BV(0)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL1 ~_BV(1)  /* Brown-out Detector trigger level */
+#define FUSE_BODLEVEL2 ~_BV(2)  /* Brown-out Detector trigger level */
+#define FUSE_EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define FUSE_WDTON     ~_BV(4)  /* Watchdog Timer Always On */
+#define FUSE_SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define FUSE_DWEN      ~_BV(6)  /* debugWIRE Enable */
+#define FUSE_RSTDISBL  ~_BV(7)  /* External reset disable */
+#define HFUSE_DEFAULT (FUSE_SPIEN)
 
 /* Extended Fuse Byte */
-#define SELFPRGEN ~_BV(0)  /* Self Programming Enable */
-#define EFUSE_DEFAULT (0xFF)
+#define FUSE_BOOTRST ~_BV(0)
+#define FUSE_BOOTSZ0 ~_BV(1)
+#define FUSE_BOOTSZ1 ~_BV(2)
+#define EFUSE_DEFAULT (FUSE_BOOTSZ0 & FUSE_BOOTSZ1)
 
 
 
