@@ -14,7 +14,7 @@
 
    * Neither the name of the copyright holders nor the names of
      contributors may be used to endorse or promote products derived
-     from this software without specific prior written permission	.
+     from this software without specific prior written permission.
 
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn13.h,v 1.6.2.2 2007/12/12 04:39:28 arcanum Exp $ */
+/* $Id: iotn13.h,v 1.8.2.3 2008/01/09 16:07:48 arcanum Exp $ */
 
 /* avr/iotn13.h - definitions for ATtiny13 */
 
@@ -259,7 +259,7 @@
 
 /* General Interrupt Flag Register */
 #define GIFR                 _SFR_IO8(0x3a)
-#  define INF0                 6
+#  define INTF0                6
 #  define PCIF                 5
 
 /* General Interrupt MaSK register */
@@ -331,22 +331,22 @@
 #define FUSE_MEMORY_SIZE 2
 
 /* Low Fuse Byte */
-#define CKSEL0      ~_BV(0)
-#define CKSEL1      ~_BV(1)
-#define SUT0        ~_BV(2)
-#define SUT1        ~_BV(3)
-#define CKDIV8      ~_BV(4)
-#define WDTON       ~_BV(5)
-#define EESAVE      ~_BV(6)
-#define SPIEN       ~_BV(7)
-#define LFUSE_DEFAULT (CKSEL0 & SUT0 & CKDIV8 & SPIEN)
+#define FUSE_CKSEL0      ~_BV(0)
+#define FUSE_CKSEL1      ~_BV(1)
+#define FUSE_SUT0        ~_BV(2)
+#define FUSE_SUT1        ~_BV(3)
+#define FUSE_CKDIV8      ~_BV(4)
+#define FUSE_WDTON       ~_BV(5)
+#define FUSE_EESAVE      ~_BV(6)
+#define FUSE_SPIEN       ~_BV(7)
+#define LFUSE_DEFAULT (FUSE_CKSEL0 & FUSE_SUT0 & FUSE_CKDIV8 & FUSE_SPIEN)
 
 /* High Fuse Byte */
-#define RSTDISBL    ~_BV(0)
-#define BODLEVEL0   ~_BV(1)
-#define BODLEVEL1   ~_BV(2)
-#define DWEN        ~_BV(3)
-#define SPMEN       ~_BV(4)
+#define FUSE_RSTDISBL    ~_BV(0)
+#define FUSE_BODLEVEL0   ~_BV(1)
+#define FUSE_BODLEVEL1   ~_BV(2)
+#define FUSE_DWEN        ~_BV(3)
+#define FUSE_SPMEN       ~_BV(4)
 #define HFUSE_DEFAULT (0xFF)
 
 
